# coding: utf-8
import pprint
import six
from enum import Enum



class Refund:

    swagger_types = {
    
        'amount': 'float',
        'base_line_items': 'list[LineItem]',
        'completion': 'int',
        'created_by': 'int',
        'created_on': 'datetime',
        'environment': 'Environment',
        'external_id': 'str',
        'failed_on': 'datetime',
        'failure_reason': 'FailureReason',
        'id': 'int',
        'labels': 'list[Label]',
        'language': 'str',
        'line_items': 'list[LineItem]',
        'linked_space_id': 'int',
        'merchant_reference': 'str',
        'next_update_on': 'datetime',
        'planned_purge_date': 'datetime',
        'processing_on': 'datetime',
        'processor_reference': 'str',
        'reduced_line_items': 'list[LineItem]',
        'reductions': 'list[LineItemReduction]',
        'state': 'RefundState',
        'succeeded_on': 'datetime',
        'taxes': 'list[Tax]',
        'time_zone': 'str',
        'timeout_on': 'datetime',
        'total_applied_fees': 'float',
        'total_settled_amount': 'float',
        'transaction': 'Transaction',
        'type': 'RefundType',
        'updated_invoice': 'int',
        'version': 'int',
    }

    attribute_map = {
        'amount': 'amount','base_line_items': 'baseLineItems','completion': 'completion','created_by': 'createdBy','created_on': 'createdOn','environment': 'environment','external_id': 'externalId','failed_on': 'failedOn','failure_reason': 'failureReason','id': 'id','labels': 'labels','language': 'language','line_items': 'lineItems','linked_space_id': 'linkedSpaceId','merchant_reference': 'merchantReference','next_update_on': 'nextUpdateOn','planned_purge_date': 'plannedPurgeDate','processing_on': 'processingOn','processor_reference': 'processorReference','reduced_line_items': 'reducedLineItems','reductions': 'reductions','state': 'state','succeeded_on': 'succeededOn','taxes': 'taxes','time_zone': 'timeZone','timeout_on': 'timeoutOn','total_applied_fees': 'totalAppliedFees','total_settled_amount': 'totalSettledAmount','transaction': 'transaction','type': 'type','updated_invoice': 'updatedInvoice','version': 'version',
    }

    
    _amount = None
    _base_line_items = None
    _completion = None
    _created_by = None
    _created_on = None
    _environment = None
    _external_id = None
    _failed_on = None
    _failure_reason = None
    _id = None
    _labels = None
    _language = None
    _line_items = None
    _linked_space_id = None
    _merchant_reference = None
    _next_update_on = None
    _planned_purge_date = None
    _processing_on = None
    _processor_reference = None
    _reduced_line_items = None
    _reductions = None
    _state = None
    _succeeded_on = None
    _taxes = None
    _time_zone = None
    _timeout_on = None
    _total_applied_fees = None
    _total_settled_amount = None
    _transaction = None
    _type = None
    _updated_invoice = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount = kwargs.get('amount', None)
        self.base_line_items = kwargs.get('base_line_items', None)
        self.completion = kwargs.get('completion', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.environment = kwargs.get('environment', None)
        self.external_id = kwargs.get('external_id', None)
        self.failed_on = kwargs.get('failed_on', None)
        self.failure_reason = kwargs.get('failure_reason', None)
        self.id = kwargs.get('id', None)
        self.labels = kwargs.get('labels', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.merchant_reference = kwargs.get('merchant_reference', None)
        self.next_update_on = kwargs.get('next_update_on', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.processing_on = kwargs.get('processing_on', None)
        self.processor_reference = kwargs.get('processor_reference', None)
        self.reduced_line_items = kwargs.get('reduced_line_items', None)
        self.reductions = kwargs.get('reductions', None)
        self.state = kwargs.get('state', None)
        self.succeeded_on = kwargs.get('succeeded_on', None)
        self.taxes = kwargs.get('taxes', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.timeout_on = kwargs.get('timeout_on', None)
        self.total_applied_fees = kwargs.get('total_applied_fees', None)
        self.total_settled_amount = kwargs.get('total_settled_amount', None)
        self.transaction = kwargs.get('transaction', None)
        self.type = kwargs.get('type', None)
        self.updated_invoice = kwargs.get('updated_invoice', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def amount(self):
        """Gets the amount of this Refund.

            

        :return: The amount of this Refund.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Refund.

            

        :param amount: The amount of this Refund.
        :type: float
        """

        self._amount = amount
    
    @property
    def base_line_items(self):
        """Gets the base_line_items of this Refund.

            

        :return: The base_line_items of this Refund.
        :rtype: list[LineItem]
        """
        return self._base_line_items

    @base_line_items.setter
    def base_line_items(self, base_line_items):
        """Sets the base_line_items of this Refund.

            

        :param base_line_items: The base_line_items of this Refund.
        :type: list[LineItem]
        """

        self._base_line_items = base_line_items
    
    @property
    def completion(self):
        """Gets the completion of this Refund.

            

        :return: The completion of this Refund.
        :rtype: int
        """
        return self._completion

    @completion.setter
    def completion(self, completion):
        """Sets the completion of this Refund.

            

        :param completion: The completion of this Refund.
        :type: int
        """

        self._completion = completion
    
    @property
    def created_by(self):
        """Gets the created_by of this Refund.

            

        :return: The created_by of this Refund.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this Refund.

            

        :param created_by: The created_by of this Refund.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this Refund.

            The created on date indicates the date on which the entity was stored into the database.

        :return: The created_on of this Refund.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this Refund.

            The created on date indicates the date on which the entity was stored into the database.

        :param created_on: The created_on of this Refund.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def environment(self):
        """Gets the environment of this Refund.

            

        :return: The environment of this Refund.
        :rtype: Environment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this Refund.

            

        :param environment: The environment of this Refund.
        :type: Environment
        """

        self._environment = environment
    
    @property
    def external_id(self):
        """Gets the external_id of this Refund.

            The external id helps to identify duplicate calls to the refund service. As such the external ID has to be unique per transaction.

        :return: The external_id of this Refund.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this Refund.

            The external id helps to identify duplicate calls to the refund service. As such the external ID has to be unique per transaction.

        :param external_id: The external_id of this Refund.
        :type: str
        """
        if external_id is not None and len(external_id) > 100:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `100`")
        if external_id is not None and len(external_id) < 1:
            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")

        self._external_id = external_id
    
    @property
    def failed_on(self):
        """Gets the failed_on of this Refund.

            

        :return: The failed_on of this Refund.
        :rtype: datetime
        """
        return self._failed_on

    @failed_on.setter
    def failed_on(self, failed_on):
        """Sets the failed_on of this Refund.

            

        :param failed_on: The failed_on of this Refund.
        :type: datetime
        """

        self._failed_on = failed_on
    
    @property
    def failure_reason(self):
        """Gets the failure_reason of this Refund.

            

        :return: The failure_reason of this Refund.
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this Refund.

            

        :param failure_reason: The failure_reason of this Refund.
        :type: FailureReason
        """

        self._failure_reason = failure_reason
    
    @property
    def id(self):
        """Gets the id of this Refund.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this Refund.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Refund.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this Refund.
        :type: int
        """

        self._id = id
    
    @property
    def labels(self):
        """Gets the labels of this Refund.

            

        :return: The labels of this Refund.
        :rtype: list[Label]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this Refund.

            

        :param labels: The labels of this Refund.
        :type: list[Label]
        """

        self._labels = labels
    
    @property
    def language(self):
        """Gets the language of this Refund.

            

        :return: The language of this Refund.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Refund.

            

        :param language: The language of this Refund.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this Refund.

            

        :return: The line_items of this Refund.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this Refund.

            

        :param line_items: The line_items of this Refund.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this Refund.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this Refund.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this Refund.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this Refund.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def merchant_reference(self):
        """Gets the merchant_reference of this Refund.

            

        :return: The merchant_reference of this Refund.
        :rtype: str
        """
        return self._merchant_reference

    @merchant_reference.setter
    def merchant_reference(self, merchant_reference):
        """Sets the merchant_reference of this Refund.

            

        :param merchant_reference: The merchant_reference of this Refund.
        :type: str
        """
        if merchant_reference is not None and len(merchant_reference) > 100:
            raise ValueError("Invalid value for `merchant_reference`, length must be less than or equal to `100`")

        self._merchant_reference = merchant_reference
    
    @property
    def next_update_on(self):
        """Gets the next_update_on of this Refund.

            

        :return: The next_update_on of this Refund.
        :rtype: datetime
        """
        return self._next_update_on

    @next_update_on.setter
    def next_update_on(self, next_update_on):
        """Sets the next_update_on of this Refund.

            

        :param next_update_on: The next_update_on of this Refund.
        :type: datetime
        """

        self._next_update_on = next_update_on
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Refund.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this Refund.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Refund.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this Refund.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def processing_on(self):
        """Gets the processing_on of this Refund.

            

        :return: The processing_on of this Refund.
        :rtype: datetime
        """
        return self._processing_on

    @processing_on.setter
    def processing_on(self, processing_on):
        """Sets the processing_on of this Refund.

            

        :param processing_on: The processing_on of this Refund.
        :type: datetime
        """

        self._processing_on = processing_on
    
    @property
    def processor_reference(self):
        """Gets the processor_reference of this Refund.

            

        :return: The processor_reference of this Refund.
        :rtype: str
        """
        return self._processor_reference

    @processor_reference.setter
    def processor_reference(self, processor_reference):
        """Sets the processor_reference of this Refund.

            

        :param processor_reference: The processor_reference of this Refund.
        :type: str
        """
        if processor_reference is not None and len(processor_reference) > 150:
            raise ValueError("Invalid value for `processor_reference`, length must be less than or equal to `150`")

        self._processor_reference = processor_reference
    
    @property
    def reduced_line_items(self):
        """Gets the reduced_line_items of this Refund.

            

        :return: The reduced_line_items of this Refund.
        :rtype: list[LineItem]
        """
        return self._reduced_line_items

    @reduced_line_items.setter
    def reduced_line_items(self, reduced_line_items):
        """Sets the reduced_line_items of this Refund.

            

        :param reduced_line_items: The reduced_line_items of this Refund.
        :type: list[LineItem]
        """

        self._reduced_line_items = reduced_line_items
    
    @property
    def reductions(self):
        """Gets the reductions of this Refund.

            

        :return: The reductions of this Refund.
        :rtype: list[LineItemReduction]
        """
        return self._reductions

    @reductions.setter
    def reductions(self, reductions):
        """Sets the reductions of this Refund.

            

        :param reductions: The reductions of this Refund.
        :type: list[LineItemReduction]
        """

        self._reductions = reductions
    
    @property
    def state(self):
        """Gets the state of this Refund.

            

        :return: The state of this Refund.
        :rtype: RefundState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Refund.

            

        :param state: The state of this Refund.
        :type: RefundState
        """

        self._state = state
    
    @property
    def succeeded_on(self):
        """Gets the succeeded_on of this Refund.

            

        :return: The succeeded_on of this Refund.
        :rtype: datetime
        """
        return self._succeeded_on

    @succeeded_on.setter
    def succeeded_on(self, succeeded_on):
        """Sets the succeeded_on of this Refund.

            

        :param succeeded_on: The succeeded_on of this Refund.
        :type: datetime
        """

        self._succeeded_on = succeeded_on
    
    @property
    def taxes(self):
        """Gets the taxes of this Refund.

            

        :return: The taxes of this Refund.
        :rtype: list[Tax]
        """
        return self._taxes

    @taxes.setter
    def taxes(self, taxes):
        """Sets the taxes of this Refund.

            

        :param taxes: The taxes of this Refund.
        :type: list[Tax]
        """

        self._taxes = taxes
    
    @property
    def time_zone(self):
        """Gets the time_zone of this Refund.

            

        :return: The time_zone of this Refund.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this Refund.

            

        :param time_zone: The time_zone of this Refund.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def timeout_on(self):
        """Gets the timeout_on of this Refund.

            

        :return: The timeout_on of this Refund.
        :rtype: datetime
        """
        return self._timeout_on

    @timeout_on.setter
    def timeout_on(self, timeout_on):
        """Sets the timeout_on of this Refund.

            

        :param timeout_on: The timeout_on of this Refund.
        :type: datetime
        """

        self._timeout_on = timeout_on
    
    @property
    def total_applied_fees(self):
        """Gets the total_applied_fees of this Refund.

            The total applied fees is the sum of all fees that have been applied so far.

        :return: The total_applied_fees of this Refund.
        :rtype: float
        """
        return self._total_applied_fees

    @total_applied_fees.setter
    def total_applied_fees(self, total_applied_fees):
        """Sets the total_applied_fees of this Refund.

            The total applied fees is the sum of all fees that have been applied so far.

        :param total_applied_fees: The total_applied_fees of this Refund.
        :type: float
        """

        self._total_applied_fees = total_applied_fees
    
    @property
    def total_settled_amount(self):
        """Gets the total_settled_amount of this Refund.

            The total settled amount is the total amount which has been settled so far.

        :return: The total_settled_amount of this Refund.
        :rtype: float
        """
        return self._total_settled_amount

    @total_settled_amount.setter
    def total_settled_amount(self, total_settled_amount):
        """Sets the total_settled_amount of this Refund.

            The total settled amount is the total amount which has been settled so far.

        :param total_settled_amount: The total_settled_amount of this Refund.
        :type: float
        """

        self._total_settled_amount = total_settled_amount
    
    @property
    def transaction(self):
        """Gets the transaction of this Refund.

            

        :return: The transaction of this Refund.
        :rtype: Transaction
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this Refund.

            

        :param transaction: The transaction of this Refund.
        :type: Transaction
        """

        self._transaction = transaction
    
    @property
    def type(self):
        """Gets the type of this Refund.

            

        :return: The type of this Refund.
        :rtype: RefundType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Refund.

            

        :param type: The type of this Refund.
        :type: RefundType
        """

        self._type = type
    
    @property
    def updated_invoice(self):
        """Gets the updated_invoice of this Refund.

            

        :return: The updated_invoice of this Refund.
        :rtype: int
        """
        return self._updated_invoice

    @updated_invoice.setter
    def updated_invoice(self, updated_invoice):
        """Sets the updated_invoice of this Refund.

            

        :param updated_invoice: The updated_invoice of this Refund.
        :type: int
        """

        self._updated_invoice = updated_invoice
    
    @property
    def version(self):
        """Gets the version of this Refund.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this Refund.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Refund.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this Refund.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Refund, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Refund):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class SubscriptionChargeState(Enum):
    
    SCHEDULED = "SCHEDULED"
    DISCARDED = "DISCARDED"
    PROCESSING = "PROCESSING"
    SUCCESSFUL = "SUCCESSFUL"
    FAILED = "FAILED"




# coding: utf-8
import pprint
import six
from enum import Enum



class Scope:

    swagger_types = {
    
        'domain_name': 'str',
        'features': 'list[Feature]',
        'id': 'int',
        'machine_name': 'str',
        'name': 'str',
        'planned_purge_date': 'datetime',
        'port': 'int',
        'ssl_active': 'bool',
        'state': 'CreationEntityState',
        'themes': 'list[str]',
        'url': 'str',
        'version': 'int',
    }

    attribute_map = {
        'domain_name': 'domainName','features': 'features','id': 'id','machine_name': 'machineName','name': 'name','planned_purge_date': 'plannedPurgeDate','port': 'port','ssl_active': 'sslActive','state': 'state','themes': 'themes','url': 'url','version': 'version',
    }

    
    _domain_name = None
    _features = None
    _id = None
    _machine_name = None
    _name = None
    _planned_purge_date = None
    _port = None
    _ssl_active = None
    _state = None
    _themes = None
    _url = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.domain_name = kwargs.get('domain_name', None)
        self.features = kwargs.get('features', None)
        self.id = kwargs.get('id', None)
        self.machine_name = kwargs.get('machine_name', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.port = kwargs.get('port', None)
        self.ssl_active = kwargs.get('ssl_active', None)
        self.state = kwargs.get('state', None)
        self.themes = kwargs.get('themes', None)
        self.url = kwargs.get('url', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def domain_name(self):
        """Gets the domain_name of this Scope.

            The domain name to which this scope is mapped to.

        :return: The domain_name of this Scope.
        :rtype: str
        """
        return self._domain_name

    @domain_name.setter
    def domain_name(self, domain_name):
        """Sets the domain_name of this Scope.

            The domain name to which this scope is mapped to.

        :param domain_name: The domain_name of this Scope.
        :type: str
        """
        if domain_name is not None and len(domain_name) > 40:
            raise ValueError("Invalid value for `domain_name`, length must be less than or equal to `40`")

        self._domain_name = domain_name
    
    @property
    def features(self):
        """Gets the features of this Scope.

            

        :return: The features of this Scope.
        :rtype: list[Feature]
        """
        return self._features

    @features.setter
    def features(self, features):
        """Sets the features of this Scope.

            

        :param features: The features of this Scope.
        :type: list[Feature]
        """

        self._features = features
    
    @property
    def id(self):
        """Gets the id of this Scope.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this Scope.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Scope.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this Scope.
        :type: int
        """

        self._id = id
    
    @property
    def machine_name(self):
        """Gets the machine_name of this Scope.

            

        :return: The machine_name of this Scope.
        :rtype: str
        """
        return self._machine_name

    @machine_name.setter
    def machine_name(self, machine_name):
        """Sets the machine_name of this Scope.

            

        :param machine_name: The machine_name of this Scope.
        :type: str
        """
        if machine_name is not None and len(machine_name) > 50:
            raise ValueError("Invalid value for `machine_name`, length must be less than or equal to `50`")

        self._machine_name = machine_name
    
    @property
    def name(self):
        """Gets the name of this Scope.

            The name of the scope is shown to the user where the user should select a scope.

        :return: The name of this Scope.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Scope.

            The name of the scope is shown to the user where the user should select a scope.

        :param name: The name of this Scope.
        :type: str
        """
        if name is not None and len(name) > 50:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `50`")

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this Scope.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this Scope.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this Scope.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this Scope.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def port(self):
        """Gets the port of this Scope.

            The port number to which this scope is mapped to.

        :return: The port of this Scope.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """Sets the port of this Scope.

            The port number to which this scope is mapped to.

        :param port: The port of this Scope.
        :type: int
        """

        self._port = port
    
    @property
    def ssl_active(self):
        """Gets the ssl_active of this Scope.

            Define whether the scope supports SSL.

        :return: The ssl_active of this Scope.
        :rtype: bool
        """
        return self._ssl_active

    @ssl_active.setter
    def ssl_active(self, ssl_active):
        """Sets the ssl_active of this Scope.

            Define whether the scope supports SSL.

        :param ssl_active: The ssl_active of this Scope.
        :type: bool
        """

        self._ssl_active = ssl_active
    
    @property
    def state(self):
        """Gets the state of this Scope.

            

        :return: The state of this Scope.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this Scope.

            

        :param state: The state of this Scope.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def themes(self):
        """Gets the themes of this Scope.

            The themes determines how the application layout, look and feel is. By providing multiple themes you can fallback to other themes.

        :return: The themes of this Scope.
        :rtype: list[str]
        """
        return self._themes

    @themes.setter
    def themes(self, themes):
        """Sets the themes of this Scope.

            The themes determines how the application layout, look and feel is. By providing multiple themes you can fallback to other themes.

        :param themes: The themes of this Scope.
        :type: list[str]
        """

        self._themes = themes
    
    @property
    def url(self):
        """Gets the url of this Scope.

            

        :return: The url of this Scope.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Scope.

            

        :param url: The url of this Scope.
        :type: str
        """

        self._url = url
    
    @property
    def version(self):
        """Gets the version of this Scope.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this Scope.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this Scope.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this Scope.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(Scope, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, Scope):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class TerminalReceiptFetchRequest:

    swagger_types = {
    
        'format': 'TerminalReceiptFormat',
        'transaction': 'int',
        'width': 'int',
    }

    attribute_map = {
        'format': 'format','transaction': 'transaction','width': 'width',
    }

    
    _format = None
    _transaction = None
    _width = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.format = kwargs.get('format')

        self.transaction = kwargs.get('transaction')

        self.width = kwargs.get('width', None)
        

    
    @property
    def format(self):
        """Gets the format of this TerminalReceiptFetchRequest.

            The format determines in what format the receipts will be returned in.

        :return: The format of this TerminalReceiptFetchRequest.
        :rtype: TerminalReceiptFormat
        """
        return self._format

    @format.setter
    def format(self, format):
        """Sets the format of this TerminalReceiptFetchRequest.

            The format determines in what format the receipts will be returned in.

        :param format: The format of this TerminalReceiptFetchRequest.
        :type: TerminalReceiptFormat
        """
        if format is None:
            raise ValueError("Invalid value for `format`, must not be `None`")

        self._format = format
    
    @property
    def transaction(self):
        """Gets the transaction of this TerminalReceiptFetchRequest.

            Provide here the ID of the transaction for which the receipts should be fetched.

        :return: The transaction of this TerminalReceiptFetchRequest.
        :rtype: int
        """
        return self._transaction

    @transaction.setter
    def transaction(self, transaction):
        """Sets the transaction of this TerminalReceiptFetchRequest.

            Provide here the ID of the transaction for which the receipts should be fetched.

        :param transaction: The transaction of this TerminalReceiptFetchRequest.
        :type: int
        """
        if transaction is None:
            raise ValueError("Invalid value for `transaction`, must not be `None`")

        self._transaction = transaction
    
    @property
    def width(self):
        """Gets the width of this TerminalReceiptFetchRequest.

            The width controls how width the document will be rendered. In case of the PDF format the width is in mm. In case of the text format the width is in the number of chars per line.

        :return: The width of this TerminalReceiptFetchRequest.
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this TerminalReceiptFetchRequest.

            The width controls how width the document will be rendered. In case of the PDF format the width is in mm. In case of the text format the width is in the number of chars per line.

        :param width: The width of this TerminalReceiptFetchRequest.
        :type: int
        """

        self._width = width
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TerminalReceiptFetchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TerminalReceiptFetchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class CustomerPostalAddress:

    swagger_types = {
    
        'city': 'str',
        'commercial_register_number': 'str',
        'country': 'str',
        'date_of_birth': 'date',
        'dependent_locality': 'str',
        'email_address': 'str',
        'family_name': 'str',
        'gender': 'Gender',
        'given_name': 'str',
        'legal_organization_form': 'LegalOrganizationForm',
        'mobile_phone_number': 'str',
        'organization_name': 'str',
        'phone_number': 'str',
        'postal_state': 'str',
        'postcode': 'str',
        'sales_tax_number': 'str',
        'salutation': 'str',
        'social_security_number': 'str',
        'sorting_code': 'str',
        'street': 'str',
    }

    attribute_map = {
        'city': 'city','commercial_register_number': 'commercialRegisterNumber','country': 'country','date_of_birth': 'dateOfBirth','dependent_locality': 'dependentLocality','email_address': 'emailAddress','family_name': 'familyName','gender': 'gender','given_name': 'givenName','legal_organization_form': 'legalOrganizationForm','mobile_phone_number': 'mobilePhoneNumber','organization_name': 'organizationName','phone_number': 'phoneNumber','postal_state': 'postalState','postcode': 'postcode','sales_tax_number': 'salesTaxNumber','salutation': 'salutation','social_security_number': 'socialSecurityNumber','sorting_code': 'sortingCode','street': 'street',
    }

    
    _city = None
    _commercial_register_number = None
    _country = None
    _date_of_birth = None
    _dependent_locality = None
    _email_address = None
    _family_name = None
    _gender = None
    _given_name = None
    _legal_organization_form = None
    _mobile_phone_number = None
    _organization_name = None
    _phone_number = None
    _postal_state = None
    _postcode = None
    _sales_tax_number = None
    _salutation = None
    _social_security_number = None
    _sorting_code = None
    _street = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.city = kwargs.get('city', None)
        self.commercial_register_number = kwargs.get('commercial_register_number', None)
        self.country = kwargs.get('country', None)
        self.date_of_birth = kwargs.get('date_of_birth', None)
        self.dependent_locality = kwargs.get('dependent_locality', None)
        self.email_address = kwargs.get('email_address', None)
        self.family_name = kwargs.get('family_name', None)
        self.gender = kwargs.get('gender', None)
        self.given_name = kwargs.get('given_name', None)
        self.legal_organization_form = kwargs.get('legal_organization_form', None)
        self.mobile_phone_number = kwargs.get('mobile_phone_number', None)
        self.organization_name = kwargs.get('organization_name', None)
        self.phone_number = kwargs.get('phone_number', None)
        self.postal_state = kwargs.get('postal_state', None)
        self.postcode = kwargs.get('postcode', None)
        self.sales_tax_number = kwargs.get('sales_tax_number', None)
        self.salutation = kwargs.get('salutation', None)
        self.social_security_number = kwargs.get('social_security_number', None)
        self.sorting_code = kwargs.get('sorting_code', None)
        self.street = kwargs.get('street', None)
        

    
    @property
    def city(self):
        """Gets the city of this CustomerPostalAddress.

            

        :return: The city of this CustomerPostalAddress.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this CustomerPostalAddress.

            

        :param city: The city of this CustomerPostalAddress.
        :type: str
        """
        if city is not None and len(city) > 100:
            raise ValueError("Invalid value for `city`, length must be less than or equal to `100`")

        self._city = city
    
    @property
    def commercial_register_number(self):
        """Gets the commercial_register_number of this CustomerPostalAddress.

            

        :return: The commercial_register_number of this CustomerPostalAddress.
        :rtype: str
        """
        return self._commercial_register_number

    @commercial_register_number.setter
    def commercial_register_number(self, commercial_register_number):
        """Sets the commercial_register_number of this CustomerPostalAddress.

            

        :param commercial_register_number: The commercial_register_number of this CustomerPostalAddress.
        :type: str
        """
        if commercial_register_number is not None and len(commercial_register_number) > 100:
            raise ValueError("Invalid value for `commercial_register_number`, length must be less than or equal to `100`")

        self._commercial_register_number = commercial_register_number
    
    @property
    def country(self):
        """Gets the country of this CustomerPostalAddress.

            

        :return: The country of this CustomerPostalAddress.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this CustomerPostalAddress.

            

        :param country: The country of this CustomerPostalAddress.
        :type: str
        """

        self._country = country
    
    @property
    def date_of_birth(self):
        """Gets the date_of_birth of this CustomerPostalAddress.

            

        :return: The date_of_birth of this CustomerPostalAddress.
        :rtype: date
        """
        return self._date_of_birth

    @date_of_birth.setter
    def date_of_birth(self, date_of_birth):
        """Sets the date_of_birth of this CustomerPostalAddress.

            

        :param date_of_birth: The date_of_birth of this CustomerPostalAddress.
        :type: date
        """

        self._date_of_birth = date_of_birth
    
    @property
    def dependent_locality(self):
        """Gets the dependent_locality of this CustomerPostalAddress.

            

        :return: The dependent_locality of this CustomerPostalAddress.
        :rtype: str
        """
        return self._dependent_locality

    @dependent_locality.setter
    def dependent_locality(self, dependent_locality):
        """Sets the dependent_locality of this CustomerPostalAddress.

            

        :param dependent_locality: The dependent_locality of this CustomerPostalAddress.
        :type: str
        """
        if dependent_locality is not None and len(dependent_locality) > 100:
            raise ValueError("Invalid value for `dependent_locality`, length must be less than or equal to `100`")

        self._dependent_locality = dependent_locality
    
    @property
    def email_address(self):
        """Gets the email_address of this CustomerPostalAddress.

            

        :return: The email_address of this CustomerPostalAddress.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this CustomerPostalAddress.

            

        :param email_address: The email_address of this CustomerPostalAddress.
        :type: str
        """
        if email_address is not None and len(email_address) > 254:
            raise ValueError("Invalid value for `email_address`, length must be less than or equal to `254`")

        self._email_address = email_address
    
    @property
    def family_name(self):
        """Gets the family_name of this CustomerPostalAddress.

            

        :return: The family_name of this CustomerPostalAddress.
        :rtype: str
        """
        return self._family_name

    @family_name.setter
    def family_name(self, family_name):
        """Sets the family_name of this CustomerPostalAddress.

            

        :param family_name: The family_name of this CustomerPostalAddress.
        :type: str
        """
        if family_name is not None and len(family_name) > 100:
            raise ValueError("Invalid value for `family_name`, length must be less than or equal to `100`")

        self._family_name = family_name
    
    @property
    def gender(self):
        """Gets the gender of this CustomerPostalAddress.

            

        :return: The gender of this CustomerPostalAddress.
        :rtype: Gender
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this CustomerPostalAddress.

            

        :param gender: The gender of this CustomerPostalAddress.
        :type: Gender
        """

        self._gender = gender
    
    @property
    def given_name(self):
        """Gets the given_name of this CustomerPostalAddress.

            

        :return: The given_name of this CustomerPostalAddress.
        :rtype: str
        """
        return self._given_name

    @given_name.setter
    def given_name(self, given_name):
        """Sets the given_name of this CustomerPostalAddress.

            

        :param given_name: The given_name of this CustomerPostalAddress.
        :type: str
        """
        if given_name is not None and len(given_name) > 100:
            raise ValueError("Invalid value for `given_name`, length must be less than or equal to `100`")

        self._given_name = given_name
    
    @property
    def legal_organization_form(self):
        """Gets the legal_organization_form of this CustomerPostalAddress.

            

        :return: The legal_organization_form of this CustomerPostalAddress.
        :rtype: LegalOrganizationForm
        """
        return self._legal_organization_form

    @legal_organization_form.setter
    def legal_organization_form(self, legal_organization_form):
        """Sets the legal_organization_form of this CustomerPostalAddress.

            

        :param legal_organization_form: The legal_organization_form of this CustomerPostalAddress.
        :type: LegalOrganizationForm
        """

        self._legal_organization_form = legal_organization_form
    
    @property
    def mobile_phone_number(self):
        """Gets the mobile_phone_number of this CustomerPostalAddress.

            

        :return: The mobile_phone_number of this CustomerPostalAddress.
        :rtype: str
        """
        return self._mobile_phone_number

    @mobile_phone_number.setter
    def mobile_phone_number(self, mobile_phone_number):
        """Sets the mobile_phone_number of this CustomerPostalAddress.

            

        :param mobile_phone_number: The mobile_phone_number of this CustomerPostalAddress.
        :type: str
        """
        if mobile_phone_number is not None and len(mobile_phone_number) > 100:
            raise ValueError("Invalid value for `mobile_phone_number`, length must be less than or equal to `100`")

        self._mobile_phone_number = mobile_phone_number
    
    @property
    def organization_name(self):
        """Gets the organization_name of this CustomerPostalAddress.

            

        :return: The organization_name of this CustomerPostalAddress.
        :rtype: str
        """
        return self._organization_name

    @organization_name.setter
    def organization_name(self, organization_name):
        """Sets the organization_name of this CustomerPostalAddress.

            

        :param organization_name: The organization_name of this CustomerPostalAddress.
        :type: str
        """
        if organization_name is not None and len(organization_name) > 100:
            raise ValueError("Invalid value for `organization_name`, length must be less than or equal to `100`")

        self._organization_name = organization_name
    
    @property
    def phone_number(self):
        """Gets the phone_number of this CustomerPostalAddress.

            

        :return: The phone_number of this CustomerPostalAddress.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this CustomerPostalAddress.

            

        :param phone_number: The phone_number of this CustomerPostalAddress.
        :type: str
        """
        if phone_number is not None and len(phone_number) > 100:
            raise ValueError("Invalid value for `phone_number`, length must be less than or equal to `100`")

        self._phone_number = phone_number
    
    @property
    def postal_state(self):
        """Gets the postal_state of this CustomerPostalAddress.

            

        :return: The postal_state of this CustomerPostalAddress.
        :rtype: str
        """
        return self._postal_state

    @postal_state.setter
    def postal_state(self, postal_state):
        """Sets the postal_state of this CustomerPostalAddress.

            

        :param postal_state: The postal_state of this CustomerPostalAddress.
        :type: str
        """

        self._postal_state = postal_state
    
    @property
    def postcode(self):
        """Gets the postcode of this CustomerPostalAddress.

            

        :return: The postcode of this CustomerPostalAddress.
        :rtype: str
        """
        return self._postcode

    @postcode.setter
    def postcode(self, postcode):
        """Sets the postcode of this CustomerPostalAddress.

            

        :param postcode: The postcode of this CustomerPostalAddress.
        :type: str
        """
        if postcode is not None and len(postcode) > 40:
            raise ValueError("Invalid value for `postcode`, length must be less than or equal to `40`")

        self._postcode = postcode
    
    @property
    def sales_tax_number(self):
        """Gets the sales_tax_number of this CustomerPostalAddress.

            

        :return: The sales_tax_number of this CustomerPostalAddress.
        :rtype: str
        """
        return self._sales_tax_number

    @sales_tax_number.setter
    def sales_tax_number(self, sales_tax_number):
        """Sets the sales_tax_number of this CustomerPostalAddress.

            

        :param sales_tax_number: The sales_tax_number of this CustomerPostalAddress.
        :type: str
        """
        if sales_tax_number is not None and len(sales_tax_number) > 100:
            raise ValueError("Invalid value for `sales_tax_number`, length must be less than or equal to `100`")

        self._sales_tax_number = sales_tax_number
    
    @property
    def salutation(self):
        """Gets the salutation of this CustomerPostalAddress.

            

        :return: The salutation of this CustomerPostalAddress.
        :rtype: str
        """
        return self._salutation

    @salutation.setter
    def salutation(self, salutation):
        """Sets the salutation of this CustomerPostalAddress.

            

        :param salutation: The salutation of this CustomerPostalAddress.
        :type: str
        """
        if salutation is not None and len(salutation) > 20:
            raise ValueError("Invalid value for `salutation`, length must be less than or equal to `20`")

        self._salutation = salutation
    
    @property
    def social_security_number(self):
        """Gets the social_security_number of this CustomerPostalAddress.

            

        :return: The social_security_number of this CustomerPostalAddress.
        :rtype: str
        """
        return self._social_security_number

    @social_security_number.setter
    def social_security_number(self, social_security_number):
        """Sets the social_security_number of this CustomerPostalAddress.

            

        :param social_security_number: The social_security_number of this CustomerPostalAddress.
        :type: str
        """
        if social_security_number is not None and len(social_security_number) > 100:
            raise ValueError("Invalid value for `social_security_number`, length must be less than or equal to `100`")

        self._social_security_number = social_security_number
    
    @property
    def sorting_code(self):
        """Gets the sorting_code of this CustomerPostalAddress.

            The sorting code identifies the post office at which the post box is located in.

        :return: The sorting_code of this CustomerPostalAddress.
        :rtype: str
        """
        return self._sorting_code

    @sorting_code.setter
    def sorting_code(self, sorting_code):
        """Sets the sorting_code of this CustomerPostalAddress.

            The sorting code identifies the post office at which the post box is located in.

        :param sorting_code: The sorting_code of this CustomerPostalAddress.
        :type: str
        """
        if sorting_code is not None and len(sorting_code) > 100:
            raise ValueError("Invalid value for `sorting_code`, length must be less than or equal to `100`")

        self._sorting_code = sorting_code
    
    @property
    def street(self):
        """Gets the street of this CustomerPostalAddress.

            

        :return: The street of this CustomerPostalAddress.
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """Sets the street of this CustomerPostalAddress.

            

        :param street: The street of this CustomerPostalAddress.
        :type: str
        """
        if street is not None and len(street) > 300:
            raise ValueError("Invalid value for `street`, length must be less than or equal to `300`")

        self._street = street
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(CustomerPostalAddress, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, CustomerPostalAddress):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class ShopifyTransactionState(Enum):
    
    PENDING = "PENDING"
    AUTHORIZED = "AUTHORIZED"
    COMPLETED = "COMPLETED"
    FAILED = "FAILED"
    CONFLICTING = "CONFLICTING"




# coding: utf-8
import pprint
import six
from enum import Enum



class AnalyticsQueryExecution:

    swagger_types = {
    
        'account': 'int',
        'external_id': 'str',
        'failure_reason': 'FailureReason',
        'id': 'int',
        'processing_end_time': 'datetime',
        'processing_start_time': 'datetime',
        'query_string': 'str',
        'scanned_data_in_gb': 'float',
        'scanned_data_limit': 'float',
        'spaces': 'list[int]',
        'state': 'AnalyticsQueryExecutionState',
    }

    attribute_map = {
        'account': 'account','external_id': 'externalId','failure_reason': 'failureReason','id': 'id','processing_end_time': 'processingEndTime','processing_start_time': 'processingStartTime','query_string': 'queryString','scanned_data_in_gb': 'scannedDataInGb','scanned_data_limit': 'scannedDataLimit','spaces': 'spaces','state': 'state',
    }

    
    _account = None
    _external_id = None
    _failure_reason = None
    _id = None
    _processing_end_time = None
    _processing_start_time = None
    _query_string = None
    _scanned_data_in_gb = None
    _scanned_data_limit = None
    _spaces = None
    _state = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.account = kwargs.get('account', None)
        self.external_id = kwargs.get('external_id', None)
        self.failure_reason = kwargs.get('failure_reason', None)
        self.id = kwargs.get('id', None)
        self.processing_end_time = kwargs.get('processing_end_time', None)
        self.processing_start_time = kwargs.get('processing_start_time', None)
        self.query_string = kwargs.get('query_string', None)
        self.scanned_data_in_gb = kwargs.get('scanned_data_in_gb', None)
        self.scanned_data_limit = kwargs.get('scanned_data_limit', None)
        self.spaces = kwargs.get('spaces', None)
        self.state = kwargs.get('state', None)
        

    
    @property
    def account(self):
        """Gets the account of this AnalyticsQueryExecution.

            The account in which the query has been executed.

        :return: The account of this AnalyticsQueryExecution.
        :rtype: int
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this AnalyticsQueryExecution.

            The account in which the query has been executed.

        :param account: The account of this AnalyticsQueryExecution.
        :type: int
        """

        self._account = account
    
    @property
    def external_id(self):
        """Gets the external_id of this AnalyticsQueryExecution.

            The External ID of the query if one had been specified; otherwise null.

        :return: The external_id of this AnalyticsQueryExecution.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this AnalyticsQueryExecution.

            The External ID of the query if one had been specified; otherwise null.

        :param external_id: The external_id of this AnalyticsQueryExecution.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def failure_reason(self):
        """Gets the failure_reason of this AnalyticsQueryExecution.

            The reason of the failure if and only if the query has failed, otherwise null.

        :return: The failure_reason of this AnalyticsQueryExecution.
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this AnalyticsQueryExecution.

            The reason of the failure if and only if the query has failed, otherwise null.

        :param failure_reason: The failure_reason of this AnalyticsQueryExecution.
        :type: FailureReason
        """

        self._failure_reason = failure_reason
    
    @property
    def id(self):
        """Gets the id of this AnalyticsQueryExecution.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this AnalyticsQueryExecution.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this AnalyticsQueryExecution.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this AnalyticsQueryExecution.
        :type: int
        """

        self._id = id
    
    @property
    def processing_end_time(self):
        """Gets the processing_end_time of this AnalyticsQueryExecution.

            The time at which processing of the query has finished (either successfully or by failure or by cancelation). Will be null if the query execution has not finished yet.

        :return: The processing_end_time of this AnalyticsQueryExecution.
        :rtype: datetime
        """
        return self._processing_end_time

    @processing_end_time.setter
    def processing_end_time(self, processing_end_time):
        """Sets the processing_end_time of this AnalyticsQueryExecution.

            The time at which processing of the query has finished (either successfully or by failure or by cancelation). Will be null if the query execution has not finished yet.

        :param processing_end_time: The processing_end_time of this AnalyticsQueryExecution.
        :type: datetime
        """

        self._processing_end_time = processing_end_time
    
    @property
    def processing_start_time(self):
        """Gets the processing_start_time of this AnalyticsQueryExecution.

            The time at which processing of the query has started (never null).

        :return: The processing_start_time of this AnalyticsQueryExecution.
        :rtype: datetime
        """
        return self._processing_start_time

    @processing_start_time.setter
    def processing_start_time(self, processing_start_time):
        """Sets the processing_start_time of this AnalyticsQueryExecution.

            The time at which processing of the query has started (never null).

        :param processing_start_time: The processing_start_time of this AnalyticsQueryExecution.
        :type: datetime
        """

        self._processing_start_time = processing_start_time
    
    @property
    def query_string(self):
        """Gets the query_string of this AnalyticsQueryExecution.

            The SQL statement which has been submitted for execution.

        :return: The query_string of this AnalyticsQueryExecution.
        :rtype: str
        """
        return self._query_string

    @query_string.setter
    def query_string(self, query_string):
        """Sets the query_string of this AnalyticsQueryExecution.

            The SQL statement which has been submitted for execution.

        :param query_string: The query_string of this AnalyticsQueryExecution.
        :type: str
        """

        self._query_string = query_string
    
    @property
    def scanned_data_in_gb(self):
        """Gets the scanned_data_in_gb of this AnalyticsQueryExecution.

            The amount of data scanned while processing the query (in GB). (Note that this amount may increase over time while the query is still being processed and not finished yet.)

        :return: The scanned_data_in_gb of this AnalyticsQueryExecution.
        :rtype: float
        """
        return self._scanned_data_in_gb

    @scanned_data_in_gb.setter
    def scanned_data_in_gb(self, scanned_data_in_gb):
        """Sets the scanned_data_in_gb of this AnalyticsQueryExecution.

            The amount of data scanned while processing the query (in GB). (Note that this amount may increase over time while the query is still being processed and not finished yet.)

        :param scanned_data_in_gb: The scanned_data_in_gb of this AnalyticsQueryExecution.
        :type: float
        """

        self._scanned_data_in_gb = scanned_data_in_gb
    
    @property
    def scanned_data_limit(self):
        """Gets the scanned_data_limit of this AnalyticsQueryExecution.

            The maximal amount of scanned data that this query is allowed to scan. After this limit is reached query will be canceled by the system. 

        :return: The scanned_data_limit of this AnalyticsQueryExecution.
        :rtype: float
        """
        return self._scanned_data_limit

    @scanned_data_limit.setter
    def scanned_data_limit(self, scanned_data_limit):
        """Sets the scanned_data_limit of this AnalyticsQueryExecution.

            The maximal amount of scanned data that this query is allowed to scan. After this limit is reached query will be canceled by the system. 

        :param scanned_data_limit: The scanned_data_limit of this AnalyticsQueryExecution.
        :type: float
        """

        self._scanned_data_limit = scanned_data_limit
    
    @property
    def spaces(self):
        """Gets the spaces of this AnalyticsQueryExecution.

            The spaces in which the query has been executed. May be empty if all spaces of the specified account have been queried.

        :return: The spaces of this AnalyticsQueryExecution.
        :rtype: list[int]
        """
        return self._spaces

    @spaces.setter
    def spaces(self, spaces):
        """Sets the spaces of this AnalyticsQueryExecution.

            The spaces in which the query has been executed. May be empty if all spaces of the specified account have been queried.

        :param spaces: The spaces of this AnalyticsQueryExecution.
        :type: list[int]
        """

        self._spaces = spaces
    
    @property
    def state(self):
        """Gets the state of this AnalyticsQueryExecution.

            The current state of the query execution.

        :return: The state of this AnalyticsQueryExecution.
        :rtype: AnalyticsQueryExecutionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AnalyticsQueryExecution.

            The current state of the query execution.

        :param state: The state of this AnalyticsQueryExecution.
        :type: AnalyticsQueryExecutionState
        """

        self._state = state
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(AnalyticsQueryExecution, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, AnalyticsQueryExecution):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class TokenizedCardData:

    swagger_types = {
    
        'cryptogram': 'CardCryptogram',
        'recurring_indicator': 'RecurringIndicator',
        'token_requestor_id': 'str',
    }

    attribute_map = {
        'cryptogram': 'cryptogram','recurring_indicator': 'recurringIndicator','token_requestor_id': 'tokenRequestorId',
    }

    
    _cryptogram = None
    _recurring_indicator = None
    _token_requestor_id = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.cryptogram = kwargs.get('cryptogram', None)
        self.recurring_indicator = kwargs.get('recurring_indicator', None)
        self.token_requestor_id = kwargs.get('token_requestor_id', None)
        

    
    @property
    def cryptogram(self):
        """Gets the cryptogram of this TokenizedCardData.

            The additional authentication value used to secure the tokenized card transactions.

        :return: The cryptogram of this TokenizedCardData.
        :rtype: CardCryptogram
        """
        return self._cryptogram

    @cryptogram.setter
    def cryptogram(self, cryptogram):
        """Sets the cryptogram of this TokenizedCardData.

            The additional authentication value used to secure the tokenized card transactions.

        :param cryptogram: The cryptogram of this TokenizedCardData.
        :type: CardCryptogram
        """

        self._cryptogram = cryptogram
    
    @property
    def recurring_indicator(self):
        """Gets the recurring_indicator of this TokenizedCardData.

            

        :return: The recurring_indicator of this TokenizedCardData.
        :rtype: RecurringIndicator
        """
        return self._recurring_indicator

    @recurring_indicator.setter
    def recurring_indicator(self, recurring_indicator):
        """Sets the recurring_indicator of this TokenizedCardData.

            

        :param recurring_indicator: The recurring_indicator of this TokenizedCardData.
        :type: RecurringIndicator
        """

        self._recurring_indicator = recurring_indicator
    
    @property
    def token_requestor_id(self):
        """Gets the token_requestor_id of this TokenizedCardData.

            

        :return: The token_requestor_id of this TokenizedCardData.
        :rtype: str
        """
        return self._token_requestor_id

    @token_requestor_id.setter
    def token_requestor_id(self, token_requestor_id):
        """Sets the token_requestor_id of this TokenizedCardData.

            

        :param token_requestor_id: The token_requestor_id of this TokenizedCardData.
        :type: str
        """

        self._token_requestor_id = token_requestor_id
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TokenizedCardData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TokenizedCardData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class PaymentInitiationAdviceFileState(Enum):
    
    CREATED = "CREATED"
    UPLOADED = "UPLOADED"
    DOWNLOADED = "DOWNLOADED"
    PROCESSED = "PROCESSED"




# coding: utf-8
from enum import Enum, unique


@unique
class ShopifyRecurringOrderState(Enum):
    
    PENDING = "PENDING"
    ONHOLD = "ONHOLD"
    PROCESSING = "PROCESSING"
    CANCELED = "CANCELED"
    BILLED = "BILLED"
    FAILED = "FAILED"




# coding: utf-8
from enum import Enum, unique


@unique
class InvoiceReimbursementState(Enum):
    
    PENDING = "PENDING"
    MANUAL_REVIEW = "MANUAL_REVIEW"
    PROCESSING = "PROCESSING"
    PROCESSED = "PROCESSED"
    DISCARDED = "DISCARDED"




# coding: utf-8
import pprint
import six
from enum import Enum



class InstallmentPlanConfiguration:

    swagger_types = {
    
        'base_currency': 'str',
        'conditions': 'list[int]',
        'id': 'int',
        'installment_fee': 'float',
        'interest_rate': 'float',
        'linked_space_id': 'int',
        'minimal_amount': 'float',
        'name': 'str',
        'payment_method_configurations': 'list[int]',
        'planned_purge_date': 'datetime',
        'sort_order': 'int',
        'space_reference': 'SpaceReference',
        'state': 'CreationEntityState',
        'tax_class': 'TaxClass',
        'terms_and_conditions': 'ResourcePath',
        'title': 'DatabaseTranslatedString',
        'version': 'int',
    }

    attribute_map = {
        'base_currency': 'baseCurrency','conditions': 'conditions','id': 'id','installment_fee': 'installmentFee','interest_rate': 'interestRate','linked_space_id': 'linkedSpaceId','minimal_amount': 'minimalAmount','name': 'name','payment_method_configurations': 'paymentMethodConfigurations','planned_purge_date': 'plannedPurgeDate','sort_order': 'sortOrder','space_reference': 'spaceReference','state': 'state','tax_class': 'taxClass','terms_and_conditions': 'termsAndConditions','title': 'title','version': 'version',
    }

    
    _base_currency = None
    _conditions = None
    _id = None
    _installment_fee = None
    _interest_rate = None
    _linked_space_id = None
    _minimal_amount = None
    _name = None
    _payment_method_configurations = None
    _planned_purge_date = None
    _sort_order = None
    _space_reference = None
    _state = None
    _tax_class = None
    _terms_and_conditions = None
    _title = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.base_currency = kwargs.get('base_currency', None)
        self.conditions = kwargs.get('conditions', None)
        self.id = kwargs.get('id', None)
        self.installment_fee = kwargs.get('installment_fee', None)
        self.interest_rate = kwargs.get('interest_rate', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.minimal_amount = kwargs.get('minimal_amount', None)
        self.name = kwargs.get('name', None)
        self.payment_method_configurations = kwargs.get('payment_method_configurations', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.sort_order = kwargs.get('sort_order', None)
        self.space_reference = kwargs.get('space_reference', None)
        self.state = kwargs.get('state', None)
        self.tax_class = kwargs.get('tax_class', None)
        self.terms_and_conditions = kwargs.get('terms_and_conditions', None)
        self.title = kwargs.get('title', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def base_currency(self):
        """Gets the base_currency of this InstallmentPlanConfiguration.

            The base currency in which the installment fee and minimal amount are defined.

        :return: The base_currency of this InstallmentPlanConfiguration.
        :rtype: str
        """
        return self._base_currency

    @base_currency.setter
    def base_currency(self, base_currency):
        """Sets the base_currency of this InstallmentPlanConfiguration.

            The base currency in which the installment fee and minimal amount are defined.

        :param base_currency: The base_currency of this InstallmentPlanConfiguration.
        :type: str
        """

        self._base_currency = base_currency
    
    @property
    def conditions(self):
        """Gets the conditions of this InstallmentPlanConfiguration.

            If a transaction meets all selected conditions the installment plan will be available to the customer to be selected.

        :return: The conditions of this InstallmentPlanConfiguration.
        :rtype: list[int]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this InstallmentPlanConfiguration.

            If a transaction meets all selected conditions the installment plan will be available to the customer to be selected.

        :param conditions: The conditions of this InstallmentPlanConfiguration.
        :type: list[int]
        """

        self._conditions = conditions
    
    @property
    def id(self):
        """Gets the id of this InstallmentPlanConfiguration.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this InstallmentPlanConfiguration.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this InstallmentPlanConfiguration.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this InstallmentPlanConfiguration.
        :type: int
        """

        self._id = id
    
    @property
    def installment_fee(self):
        """Gets the installment_fee of this InstallmentPlanConfiguration.

            The installment fee is a fixed amount that is charged additionally when applying this installment plan.

        :return: The installment_fee of this InstallmentPlanConfiguration.
        :rtype: float
        """
        return self._installment_fee

    @installment_fee.setter
    def installment_fee(self, installment_fee):
        """Sets the installment_fee of this InstallmentPlanConfiguration.

            The installment fee is a fixed amount that is charged additionally when applying this installment plan.

        :param installment_fee: The installment_fee of this InstallmentPlanConfiguration.
        :type: float
        """

        self._installment_fee = installment_fee
    
    @property
    def interest_rate(self):
        """Gets the interest_rate of this InstallmentPlanConfiguration.

            The interest rate is a percentage of the total amount that is charged additionally when applying this installment plan.

        :return: The interest_rate of this InstallmentPlanConfiguration.
        :rtype: float
        """
        return self._interest_rate

    @interest_rate.setter
    def interest_rate(self, interest_rate):
        """Sets the interest_rate of this InstallmentPlanConfiguration.

            The interest rate is a percentage of the total amount that is charged additionally when applying this installment plan.

        :param interest_rate: The interest_rate of this InstallmentPlanConfiguration.
        :type: float
        """

        self._interest_rate = interest_rate
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this InstallmentPlanConfiguration.

            The linked space id holds the ID of the space to which the entity belongs to.

        :return: The linked_space_id of this InstallmentPlanConfiguration.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this InstallmentPlanConfiguration.

            The linked space id holds the ID of the space to which the entity belongs to.

        :param linked_space_id: The linked_space_id of this InstallmentPlanConfiguration.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def minimal_amount(self):
        """Gets the minimal_amount of this InstallmentPlanConfiguration.

            The installment plan can only be applied if the orders total is at least the defined minimal amount.

        :return: The minimal_amount of this InstallmentPlanConfiguration.
        :rtype: float
        """
        return self._minimal_amount

    @minimal_amount.setter
    def minimal_amount(self, minimal_amount):
        """Sets the minimal_amount of this InstallmentPlanConfiguration.

            The installment plan can only be applied if the orders total is at least the defined minimal amount.

        :param minimal_amount: The minimal_amount of this InstallmentPlanConfiguration.
        :type: float
        """

        self._minimal_amount = minimal_amount
    
    @property
    def name(self):
        """Gets the name of this InstallmentPlanConfiguration.

            The installment plan name is used internally to identify the plan in administrative interfaces.For example it is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this InstallmentPlanConfiguration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InstallmentPlanConfiguration.

            The installment plan name is used internally to identify the plan in administrative interfaces.For example it is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this InstallmentPlanConfiguration.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def payment_method_configurations(self):
        """Gets the payment_method_configurations of this InstallmentPlanConfiguration.

            A installment plan can be enabled only for specific payment method configurations. Other payment methods will not be selectable by the buyer.

        :return: The payment_method_configurations of this InstallmentPlanConfiguration.
        :rtype: list[int]
        """
        return self._payment_method_configurations

    @payment_method_configurations.setter
    def payment_method_configurations(self, payment_method_configurations):
        """Sets the payment_method_configurations of this InstallmentPlanConfiguration.

            A installment plan can be enabled only for specific payment method configurations. Other payment methods will not be selectable by the buyer.

        :param payment_method_configurations: The payment_method_configurations of this InstallmentPlanConfiguration.
        :type: list[int]
        """

        self._payment_method_configurations = payment_method_configurations
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this InstallmentPlanConfiguration.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :return: The planned_purge_date of this InstallmentPlanConfiguration.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this InstallmentPlanConfiguration.

            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.

        :param planned_purge_date: The planned_purge_date of this InstallmentPlanConfiguration.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def sort_order(self):
        """Gets the sort_order of this InstallmentPlanConfiguration.

            The sort order controls in which order the installation plans are listed. The sort order is used to order the plans in ascending order.

        :return: The sort_order of this InstallmentPlanConfiguration.
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this InstallmentPlanConfiguration.

            The sort order controls in which order the installation plans are listed. The sort order is used to order the plans in ascending order.

        :param sort_order: The sort_order of this InstallmentPlanConfiguration.
        :type: int
        """

        self._sort_order = sort_order
    
    @property
    def space_reference(self):
        """Gets the space_reference of this InstallmentPlanConfiguration.

            

        :return: The space_reference of this InstallmentPlanConfiguration.
        :rtype: SpaceReference
        """
        return self._space_reference

    @space_reference.setter
    def space_reference(self, space_reference):
        """Sets the space_reference of this InstallmentPlanConfiguration.

            

        :param space_reference: The space_reference of this InstallmentPlanConfiguration.
        :type: SpaceReference
        """

        self._space_reference = space_reference
    
    @property
    def state(self):
        """Gets the state of this InstallmentPlanConfiguration.

            

        :return: The state of this InstallmentPlanConfiguration.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this InstallmentPlanConfiguration.

            

        :param state: The state of this InstallmentPlanConfiguration.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def tax_class(self):
        """Gets the tax_class of this InstallmentPlanConfiguration.

            The tax class determines the taxes which are applicable on all fees linked to the installment plan.

        :return: The tax_class of this InstallmentPlanConfiguration.
        :rtype: TaxClass
        """
        return self._tax_class

    @tax_class.setter
    def tax_class(self, tax_class):
        """Sets the tax_class of this InstallmentPlanConfiguration.

            The tax class determines the taxes which are applicable on all fees linked to the installment plan.

        :param tax_class: The tax_class of this InstallmentPlanConfiguration.
        :type: TaxClass
        """

        self._tax_class = tax_class
    
    @property
    def terms_and_conditions(self):
        """Gets the terms_and_conditions of this InstallmentPlanConfiguration.

            The terms and conditions will be displayed to the customer when he or she selects this installment plan.

        :return: The terms_and_conditions of this InstallmentPlanConfiguration.
        :rtype: ResourcePath
        """
        return self._terms_and_conditions

    @terms_and_conditions.setter
    def terms_and_conditions(self, terms_and_conditions):
        """Sets the terms_and_conditions of this InstallmentPlanConfiguration.

            The terms and conditions will be displayed to the customer when he or she selects this installment plan.

        :param terms_and_conditions: The terms_and_conditions of this InstallmentPlanConfiguration.
        :type: ResourcePath
        """

        self._terms_and_conditions = terms_and_conditions
    
    @property
    def title(self):
        """Gets the title of this InstallmentPlanConfiguration.

            The title of the installment plan is used within the payment process. The title is visible to the buyer.

        :return: The title of this InstallmentPlanConfiguration.
        :rtype: DatabaseTranslatedString
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this InstallmentPlanConfiguration.

            The title of the installment plan is used within the payment process. The title is visible to the buyer.

        :param title: The title of this InstallmentPlanConfiguration.
        :type: DatabaseTranslatedString
        """

        self._title = title
    
    @property
    def version(self):
        """Gets the version of this InstallmentPlanConfiguration.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this InstallmentPlanConfiguration.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this InstallmentPlanConfiguration.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this InstallmentPlanConfiguration.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(InstallmentPlanConfiguration, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, InstallmentPlanConfiguration):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8

from __future__ import absolute_import

import six

from wallee.api_client import ApiClient

class AnalyticsQueryServiceApi:

    def __init__(self, configuration):
        self.api_client = ApiClient(configuration=configuration)

    def cancel_execution(self, id, **kwargs):
        """Cancel Execution

        Cancels the specified query execution.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_execution(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The ID of the query execution to cancel. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.cancel_execution_with_http_info(id, **kwargs)
        else:
            (data) = self.cancel_execution_with_http_info(id, **kwargs)
            return data

    def cancel_execution_with_http_info(self, id, **kwargs):
        """Cancel Execution

        Cancels the specified query execution.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.cancel_execution_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The ID of the query execution to cancel. (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method cancel_execution" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `cancel_execution`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/analytics-query/cancel-execution', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def fetch_result(self, id, **kwargs):
        """Fetch Result

        Fetches one batch of the result of a query execution.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_result(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The ID of the query execution for which to fetch the result. (required)
        :param int timeout: The maximal time in seconds to wait for the result if it is not yet available. Use 0 (the default) to return immediately without waiting.
        :param int max_rows: The maximum number of rows to return per batch. (Between 1 and 999. The default is 999.)
        :param str next_token: The next-token of the preceding batch to get the next result batch or null to get the first result batch.
        :return: AnalyticsQueryResultBatch
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.fetch_result_with_http_info(id, **kwargs)
        else:
            (data) = self.fetch_result_with_http_info(id, **kwargs)
            return data

    def fetch_result_with_http_info(self, id, **kwargs):
        """Fetch Result

        Fetches one batch of the result of a query execution.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.fetch_result_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The ID of the query execution for which to fetch the result. (required)
        :param int timeout: The maximal time in seconds to wait for the result if it is not yet available. Use 0 (the default) to return immediately without waiting.
        :param int max_rows: The maximum number of rows to return per batch. (Between 1 and 999. The default is 999.)
        :param str next_token: The next-token of the preceding batch to get the next result batch or null to get the first result batch.
        :return: AnalyticsQueryResultBatch
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'timeout', 'max_rows', 'next_token']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fetch_result" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `fetch_result`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in params:
            query_params.append(('id', params['id']))
        if 'timeout' in params:
            query_params.append(('timeout', params['timeout']))
        if 'max_rows' in params:
            query_params.append(('maxRows', params['max_rows']))
        if 'next_token' in params:
            query_params.append(('nextToken', params['next_token']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/analytics-query/fetch-result', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AnalyticsQueryResultBatch',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def generate_download_url(self, id, **kwargs):
        """Generate Download URL

        Generate a URL from which the results of a query execution can be downloaded in CSV format.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_download_url(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The ID of the query execution for which to generate the download URL. (required)
        :param int timeout: The maximal time in seconds to wait for the result if it is not yet available. Use 0 (the default) to return immediately without waiting.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.generate_download_url_with_http_info(id, **kwargs)
        else:
            (data) = self.generate_download_url_with_http_info(id, **kwargs)
            return data

    def generate_download_url_with_http_info(self, id, **kwargs):
        """Generate Download URL

        Generate a URL from which the results of a query execution can be downloaded in CSV format.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.generate_download_url_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The ID of the query execution for which to generate the download URL. (required)
        :param int timeout: The maximal time in seconds to wait for the result if it is not yet available. Use 0 (the default) to return immediately without waiting.
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id', 'timeout']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method generate_download_url" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `generate_download_url`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in params:
            query_params.append(('id', params['id']))
        if 'timeout' in params:
            query_params.append(('timeout', params['timeout']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/analytics-query/generate-download-url', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def schema(self, **kwargs):
        """Get Schemas

        Get the schemas describing the available tables and their columns.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schema(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[AnalyticsSchemaTable]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.schema_with_http_info(**kwargs)
        else:
            (data) = self.schema_with_http_info(**kwargs)
            return data

    def schema_with_http_info(self, **kwargs):
        """Get Schemas

        Get the schemas describing the available tables and their columns.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.schema_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: list[AnalyticsSchemaTable]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method schema" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/analytics-query/schema', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AnalyticsSchemaTable]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def status(self, id, **kwargs):
        """Execution Status

        Returns the current status of a query execution.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.status(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The ID of the query execution for which to get the status. (required)
        :return: AnalyticsQueryExecution
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.status_with_http_info(id, **kwargs)
        else:
            (data) = self.status_with_http_info(id, **kwargs)
            return data

    def status_with_http_info(self, id, **kwargs):
        """Execution Status

        Returns the current status of a query execution.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.status_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: The ID of the query execution for which to get the status. (required)
        :return: AnalyticsQueryExecution
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method status" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `status`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'id' in params:
            query_params.append(('id', params['id']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/analytics-query/status', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AnalyticsQueryExecution',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def submit_query(self, query, **kwargs):
        """Submit Query

        Submits a query for execution.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submit_query(query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnalyticsQuery query: The query to submit. (required)
        :return: AnalyticsQueryExecution
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True


        if kwargs.get('async_req'):
            return self.submit_query_with_http_info(query, **kwargs)
        else:
            (data) = self.submit_query_with_http_info(query, **kwargs)
            return data

    def submit_query_with_http_info(self, query, **kwargs):
        """Submit Query

        Submits a query for execution.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submit_query_with_http_info(query, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param AnalyticsQuery query: The query to submit. (required)
        :return: AnalyticsQueryExecution
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['query']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submit_query" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'query' is set
        if ('query' not in params or
                params['query'] is None):
            raise ValueError("Missing the required parameter `query` when calling `submit_query`")

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'query' in params:
            body_params = params['query']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['application/json;charset=utf-8'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/analytics-query/submit-query', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AnalyticsQueryExecution',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

from __future__ import absolute_import

from wallee.api.account_service_api import AccountServiceApi
from wallee.api.analytics_query_service_api import AnalyticsQueryServiceApi
from wallee.api.application_user_service_api import ApplicationUserServiceApi
from wallee.api.bank_account_service_api import BankAccountServiceApi
from wallee.api.bank_transaction_service_api import BankTransactionServiceApi
from wallee.api.card_processing_service_api import CardProcessingServiceApi
from wallee.api.charge_attempt_service_api import ChargeAttemptServiceApi
from wallee.api.charge_bank_transaction_service_api import ChargeBankTransactionServiceApi
from wallee.api.charge_flow_level_payment_link_service_api import ChargeFlowLevelPaymentLinkServiceApi
from wallee.api.charge_flow_level_service_api import ChargeFlowLevelServiceApi
from wallee.api.charge_flow_service_api import ChargeFlowServiceApi
from wallee.api.condition_type_service_api import ConditionTypeServiceApi
from wallee.api.country_service_api import CountryServiceApi
from wallee.api.country_state_service_api import CountryStateServiceApi
from wallee.api.currency_bank_account_service_api import CurrencyBankAccountServiceApi
from wallee.api.currency_service_api import CurrencyServiceApi
from wallee.api.customer_address_service_api import CustomerAddressServiceApi
from wallee.api.customer_comment_service_api import CustomerCommentServiceApi
from wallee.api.customer_service_api import CustomerServiceApi
from wallee.api.debt_collection_case_service_api import DebtCollectionCaseServiceApi
from wallee.api.debt_collector_configuration_service_api import DebtCollectorConfigurationServiceApi
from wallee.api.debt_collector_service_api import DebtCollectorServiceApi
from wallee.api.delivery_indication_service_api import DeliveryIndicationServiceApi
from wallee.api.document_template_service_api import DocumentTemplateServiceApi
from wallee.api.document_template_type_service_api import DocumentTemplateTypeServiceApi
from wallee.api.external_transfer_bank_transaction_service_api import ExternalTransferBankTransactionServiceApi
from wallee.api.human_user_service_api import HumanUserServiceApi
from wallee.api.installment_payment_service_api import InstallmentPaymentServiceApi
from wallee.api.installment_payment_slice_service_api import InstallmentPaymentSliceServiceApi
from wallee.api.installment_plan_calculation_service_api import InstallmentPlanCalculationServiceApi
from wallee.api.installment_plan_configuration_service_api import InstallmentPlanConfigurationServiceApi
from wallee.api.installment_plan_slice_configuration_service_api import InstallmentPlanSliceConfigurationServiceApi
from wallee.api.internal_transfer_bank_transaction_service_api import InternalTransferBankTransactionServiceApi
from wallee.api.invoice_reconciliation_record_invoice_link_service_api import InvoiceReconciliationRecordInvoiceLinkServiceApi
from wallee.api.invoice_reconciliation_record_service_api import InvoiceReconciliationRecordServiceApi
from wallee.api.invoice_reimbursement_service_api import InvoiceReimbursementServiceApi
from wallee.api.label_description_group_service_api import LabelDescriptionGroupServiceApi
from wallee.api.label_description_service_api import LabelDescriptionServiceApi
from wallee.api.language_service_api import LanguageServiceApi
from wallee.api.legal_organization_form_service_api import LegalOrganizationFormServiceApi
from wallee.api.manual_task_service_api import ManualTaskServiceApi
from wallee.api.mertic_usage_service_api import MerticUsageServiceApi
from wallee.api.payment_connector_configuration_service_api import PaymentConnectorConfigurationServiceApi
from wallee.api.payment_connector_service_api import PaymentConnectorServiceApi
from wallee.api.payment_link_service_api import PaymentLinkServiceApi
from wallee.api.payment_method_brand_service_api import PaymentMethodBrandServiceApi
from wallee.api.payment_method_configuration_service_api import PaymentMethodConfigurationServiceApi
from wallee.api.payment_method_service_api import PaymentMethodServiceApi
from wallee.api.payment_processor_configuration_service_api import PaymentProcessorConfigurationServiceApi
from wallee.api.payment_processor_service_api import PaymentProcessorServiceApi
from wallee.api.payment_terminal_service_api import PaymentTerminalServiceApi
from wallee.api.payment_terminal_till_service_api import PaymentTerminalTillServiceApi
from wallee.api.payment_terminal_transaction_summary_service_api import PaymentTerminalTransactionSummaryServiceApi
from wallee.api.payment_web_app_service_api import PaymentWebAppServiceApi
from wallee.api.permission_service_api import PermissionServiceApi
from wallee.api.refund_bank_transaction_service_api import RefundBankTransactionServiceApi
from wallee.api.refund_comment_service_api import RefundCommentServiceApi
from wallee.api.refund_recovery_bank_transaction_service_api import RefundRecoveryBankTransactionServiceApi
from wallee.api.refund_service_api import RefundServiceApi
from wallee.api.shopify_recurring_order_service_api import ShopifyRecurringOrderServiceApi
from wallee.api.shopify_subscriber_service_api import ShopifySubscriberServiceApi
from wallee.api.shopify_subscription_product_service_api import ShopifySubscriptionProductServiceApi
from wallee.api.shopify_subscription_service_api import ShopifySubscriptionServiceApi
from wallee.api.shopify_subscription_suspension_service_api import ShopifySubscriptionSuspensionServiceApi
from wallee.api.shopify_subscription_version_service_api import ShopifySubscriptionVersionServiceApi
from wallee.api.shopify_transaction_service_api import ShopifyTransactionServiceApi
from wallee.api.space_service_api import SpaceServiceApi
from wallee.api.static_value_service_api import StaticValueServiceApi
from wallee.api.subscriber_service_api import SubscriberServiceApi
from wallee.api.subscription_affiliate_service_api import SubscriptionAffiliateServiceApi
from wallee.api.subscription_charge_service_api import SubscriptionChargeServiceApi
from wallee.api.subscription_ledger_entry_service_api import SubscriptionLedgerEntryServiceApi
from wallee.api.subscription_metric_service_api import SubscriptionMetricServiceApi
from wallee.api.subscription_metric_usage_service_api import SubscriptionMetricUsageServiceApi
from wallee.api.subscription_period_bill_service_api import SubscriptionPeriodBillServiceApi
from wallee.api.subscription_product_component_group_service_api import SubscriptionProductComponentGroupServiceApi
from wallee.api.subscription_product_component_service_api import SubscriptionProductComponentServiceApi
from wallee.api.subscription_product_fee_tier_service_api import SubscriptionProductFeeTierServiceApi
from wallee.api.subscription_product_metered_fee_service_api import SubscriptionProductMeteredFeeServiceApi
from wallee.api.subscription_product_period_fee_service_api import SubscriptionProductPeriodFeeServiceApi
from wallee.api.subscription_product_retirement_service_api import SubscriptionProductRetirementServiceApi
from wallee.api.subscription_product_service_api import SubscriptionProductServiceApi
from wallee.api.subscription_product_setup_fee_service_api import SubscriptionProductSetupFeeServiceApi
from wallee.api.subscription_product_version_retirement_service_api import SubscriptionProductVersionRetirementServiceApi
from wallee.api.subscription_product_version_service_api import SubscriptionProductVersionServiceApi
from wallee.api.subscription_service_api import SubscriptionServiceApi
from wallee.api.subscription_suspension_service_api import SubscriptionSuspensionServiceApi
from wallee.api.subscription_version_service_api import SubscriptionVersionServiceApi
from wallee.api.token_service_api import TokenServiceApi
from wallee.api.token_version_service_api import TokenVersionServiceApi
from wallee.api.transaction_comment_service_api import TransactionCommentServiceApi
from wallee.api.transaction_completion_service_api import TransactionCompletionServiceApi
from wallee.api.transaction_iframe_service_api import TransactionIframeServiceApi
from wallee.api.transaction_invoice_comment_service_api import TransactionInvoiceCommentServiceApi
from wallee.api.transaction_invoice_service_api import TransactionInvoiceServiceApi
from wallee.api.transaction_lightbox_service_api import TransactionLightboxServiceApi
from wallee.api.transaction_line_item_version_service_api import TransactionLineItemVersionServiceApi
from wallee.api.transaction_mobile_sdk_service_api import TransactionMobileSdkServiceApi
from wallee.api.transaction_payment_page_service_api import TransactionPaymentPageServiceApi
from wallee.api.transaction_service_api import TransactionServiceApi
from wallee.api.transaction_terminal_service_api import TransactionTerminalServiceApi
from wallee.api.transaction_void_service_api import TransactionVoidServiceApi
from wallee.api.user_account_role_service_api import UserAccountRoleServiceApi
from wallee.api.user_space_role_service_api import UserSpaceRoleServiceApi
from wallee.api.web_app_service_api import WebAppServiceApi
from wallee.api.webhook_listener_service_api import WebhookListenerServiceApi
from wallee.api.webhook_url_service_api import WebhookUrlServiceApi


from wallee.api_client import ApiClient
from wallee.configuration import Configuration

from wallee.models.abstract_account_update import AbstractAccountUpdate
from wallee.models.abstract_application_user_update import AbstractApplicationUserUpdate
from wallee.models.abstract_customer_active import AbstractCustomerActive
from wallee.models.abstract_customer_address_active import AbstractCustomerAddressActive
from wallee.models.abstract_customer_comment_active import AbstractCustomerCommentActive
from wallee.models.abstract_debt_collection_case_update import AbstractDebtCollectionCaseUpdate
from wallee.models.abstract_human_user_update import AbstractHumanUserUpdate
from wallee.models.abstract_payment_link_update import AbstractPaymentLinkUpdate
from wallee.models.abstract_refund_comment_active import AbstractRefundCommentActive
from wallee.models.abstract_shopify_subscription_product_update import AbstractShopifySubscriptionProductUpdate
from wallee.models.abstract_space_update import AbstractSpaceUpdate
from wallee.models.abstract_subscriber_update import AbstractSubscriberUpdate
from wallee.models.abstract_subscription_affiliate_update import AbstractSubscriptionAffiliateUpdate
from wallee.models.abstract_subscription_metric_update import AbstractSubscriptionMetricUpdate
from wallee.models.abstract_subscription_product_active import AbstractSubscriptionProductActive
from wallee.models.abstract_token_update import AbstractTokenUpdate
from wallee.models.abstract_transaction_comment_active import AbstractTransactionCommentActive
from wallee.models.abstract_transaction_invoice_comment_active import AbstractTransactionInvoiceCommentActive
from wallee.models.abstract_transaction_pending import AbstractTransactionPending
from wallee.models.abstract_webhook_listener_update import AbstractWebhookListenerUpdate
from wallee.models.abstract_webhook_url_update import AbstractWebhookUrlUpdate
from wallee.models.account import Account
from wallee.models.account_state import AccountState
from wallee.models.account_type import AccountType
from wallee.models.address import Address
from wallee.models.address_create import AddressCreate
from wallee.models.analytics_query import AnalyticsQuery
from wallee.models.analytics_query_execution import AnalyticsQueryExecution
from wallee.models.analytics_query_execution_state import AnalyticsQueryExecutionState
from wallee.models.analytics_query_result_batch import AnalyticsQueryResultBatch
from wallee.models.analytics_schema_column import AnalyticsSchemaColumn
from wallee.models.analytics_schema_table import AnalyticsSchemaTable
from wallee.models.authenticated_card_data_create import AuthenticatedCardDataCreate
from wallee.models.bank_account import BankAccount
from wallee.models.bank_account_environment import BankAccountEnvironment
from wallee.models.bank_account_state import BankAccountState
from wallee.models.bank_account_type import BankAccountType
from wallee.models.bank_transaction import BankTransaction
from wallee.models.bank_transaction_flow_direction import BankTransactionFlowDirection
from wallee.models.bank_transaction_source import BankTransactionSource
from wallee.models.bank_transaction_state import BankTransactionState
from wallee.models.bank_transaction_type import BankTransactionType
from wallee.models.card_authentication_response import CardAuthenticationResponse
from wallee.models.card_authentication_version import CardAuthenticationVersion
from wallee.models.card_cryptogram import CardCryptogram
from wallee.models.card_cryptogram_create import CardCryptogramCreate
from wallee.models.card_cryptogram_type import CardCryptogramType
from wallee.models.cardholder_authentication import CardholderAuthentication
from wallee.models.cardholder_authentication_create import CardholderAuthenticationCreate
from wallee.models.charge_attempt_environment import ChargeAttemptEnvironment
from wallee.models.charge_attempt_state import ChargeAttemptState
from wallee.models.charge_flow import ChargeFlow
from wallee.models.charge_flow_level_configuration import ChargeFlowLevelConfiguration
from wallee.models.charge_flow_level_configuration_type import ChargeFlowLevelConfigurationType
from wallee.models.charge_flow_level_state import ChargeFlowLevelState
from wallee.models.charge_state import ChargeState
from wallee.models.charge_type import ChargeType
from wallee.models.client_error import ClientError
from wallee.models.client_error_type import ClientErrorType
from wallee.models.completion_line_item import CompletionLineItem
from wallee.models.completion_line_item_create import CompletionLineItemCreate
from wallee.models.condition import Condition
from wallee.models.condition_type import ConditionType
from wallee.models.connector_invocation_stage import ConnectorInvocationStage
from wallee.models.creation_entity_state import CreationEntityState
from wallee.models.criteria_operator import CriteriaOperator
from wallee.models.currency_bank_account import CurrencyBankAccount
from wallee.models.customer import Customer
from wallee.models.customer_address import CustomerAddress
from wallee.models.customer_address_type import CustomerAddressType
from wallee.models.customer_comment import CustomerComment
from wallee.models.customer_postal_address import CustomerPostalAddress
from wallee.models.customer_postal_address_create import CustomerPostalAddressCreate
from wallee.models.customers_presence import CustomersPresence
from wallee.models.data_collection_type import DataCollectionType
from wallee.models.database_translated_string import DatabaseTranslatedString
from wallee.models.database_translated_string_create import DatabaseTranslatedStringCreate
from wallee.models.database_translated_string_item import DatabaseTranslatedStringItem
from wallee.models.database_translated_string_item_create import DatabaseTranslatedStringItemCreate
from wallee.models.debt_collection_case import DebtCollectionCase
from wallee.models.debt_collection_case_document import DebtCollectionCaseDocument
from wallee.models.debt_collection_case_source import DebtCollectionCaseSource
from wallee.models.debt_collection_case_state import DebtCollectionCaseState
from wallee.models.debt_collection_environment import DebtCollectionEnvironment
from wallee.models.debt_collection_receipt import DebtCollectionReceipt
from wallee.models.debt_collection_receipt_source import DebtCollectionReceiptSource
from wallee.models.debt_collector import DebtCollector
from wallee.models.debt_collector_condition import DebtCollectorCondition
from wallee.models.debt_collector_condition_type import DebtCollectorConditionType
from wallee.models.debt_collector_configuration import DebtCollectorConfiguration
from wallee.models.delivery_indication_decision_reason import DeliveryIndicationDecisionReason
from wallee.models.delivery_indication_state import DeliveryIndicationState
from wallee.models.document_template import DocumentTemplate
from wallee.models.document_template_type import DocumentTemplateType
from wallee.models.document_template_type_group import DocumentTemplateTypeGroup
from wallee.models.entity_export_request import EntityExportRequest
from wallee.models.entity_query import EntityQuery
from wallee.models.entity_query_filter import EntityQueryFilter
from wallee.models.entity_query_filter_type import EntityQueryFilterType
from wallee.models.entity_query_order_by import EntityQueryOrderBy
from wallee.models.entity_query_order_by_type import EntityQueryOrderByType
from wallee.models.environment import Environment
from wallee.models.external_transfer_bank_transaction import ExternalTransferBankTransaction
from wallee.models.failure_category import FailureCategory
from wallee.models.failure_reason import FailureReason
from wallee.models.feature import Feature
from wallee.models.feature_category import FeatureCategory
from wallee.models.gender import Gender
from wallee.models.human_user import HumanUser
from wallee.models.installment_calculated_plan import InstallmentCalculatedPlan
from wallee.models.installment_calculated_slice import InstallmentCalculatedSlice
from wallee.models.installment_payment import InstallmentPayment
from wallee.models.installment_payment_slice_state import InstallmentPaymentSliceState
from wallee.models.installment_payment_state import InstallmentPaymentState
from wallee.models.installment_plan_configuration import InstallmentPlanConfiguration
from wallee.models.installment_plan_slice_configuration import InstallmentPlanSliceConfiguration
from wallee.models.internal_transfer_bank_transaction import InternalTransferBankTransaction
from wallee.models.invoice_reconciliation_record_invoice_link import InvoiceReconciliationRecordInvoiceLink
from wallee.models.invoice_reconciliation_record_rejection_status import InvoiceReconciliationRecordRejectionStatus
from wallee.models.invoice_reconciliation_record_state import InvoiceReconciliationRecordState
from wallee.models.invoice_reconciliation_record_type import InvoiceReconciliationRecordType
from wallee.models.invoice_reimbursement import InvoiceReimbursement
from wallee.models.invoice_reimbursement_state import InvoiceReimbursementState
from wallee.models.label import Label
from wallee.models.label_descriptor import LabelDescriptor
from wallee.models.label_descriptor_category import LabelDescriptorCategory
from wallee.models.label_descriptor_group import LabelDescriptorGroup
from wallee.models.label_descriptor_type import LabelDescriptorType
from wallee.models.legal_organization_form import LegalOrganizationForm
from wallee.models.line_item import LineItem
from wallee.models.line_item_attribute import LineItemAttribute
from wallee.models.line_item_attribute_create import LineItemAttributeCreate
from wallee.models.line_item_create import LineItemCreate
from wallee.models.line_item_reduction import LineItemReduction
from wallee.models.line_item_reduction_create import LineItemReductionCreate
from wallee.models.line_item_type import LineItemType
from wallee.models.localized_string import LocalizedString
from wallee.models.manual_task import ManualTask
from wallee.models.manual_task_action import ManualTaskAction
from wallee.models.manual_task_action_style import ManualTaskActionStyle
from wallee.models.manual_task_state import ManualTaskState
from wallee.models.manual_task_type import ManualTaskType
from wallee.models.metric_usage import MetricUsage
from wallee.models.one_click_payment_mode import OneClickPaymentMode
from wallee.models.payment_adjustment import PaymentAdjustment
from wallee.models.payment_adjustment_type import PaymentAdjustmentType
from wallee.models.payment_app_charge_attempt_target_state import PaymentAppChargeAttemptTargetState
from wallee.models.payment_app_charge_attempt_update_request import PaymentAppChargeAttemptUpdateRequest
from wallee.models.payment_app_completion_configuration import PaymentAppCompletionConfiguration
from wallee.models.payment_app_completion_configuration_create import PaymentAppCompletionConfigurationCreate
from wallee.models.payment_app_completion_target_state import PaymentAppCompletionTargetState
from wallee.models.payment_app_completion_update_request import PaymentAppCompletionUpdateRequest
from wallee.models.payment_app_connector import PaymentAppConnector
from wallee.models.payment_app_connector_creation_request import PaymentAppConnectorCreationRequest
from wallee.models.payment_app_connector_state import PaymentAppConnectorState
from wallee.models.payment_app_processor import PaymentAppProcessor
from wallee.models.payment_app_processor_creation_request import PaymentAppProcessorCreationRequest
from wallee.models.payment_app_processor_state import PaymentAppProcessorState
from wallee.models.payment_app_refund_configuration import PaymentAppRefundConfiguration
from wallee.models.payment_app_refund_configuration_create import PaymentAppRefundConfigurationCreate
from wallee.models.payment_app_refund_target_state import PaymentAppRefundTargetState
from wallee.models.payment_app_refund_update_request import PaymentAppRefundUpdateRequest
from wallee.models.payment_app_void_target_state import PaymentAppVoidTargetState
from wallee.models.payment_app_void_update_request import PaymentAppVoidUpdateRequest
from wallee.models.payment_connector import PaymentConnector
from wallee.models.payment_connector_configuration import PaymentConnectorConfiguration
from wallee.models.payment_connector_feature import PaymentConnectorFeature
from wallee.models.payment_contract import PaymentContract
from wallee.models.payment_contract_state import PaymentContractState
from wallee.models.payment_contract_type import PaymentContractType
from wallee.models.payment_information_hash import PaymentInformationHash
from wallee.models.payment_information_hash_type import PaymentInformationHashType
from wallee.models.payment_initiation_advice_file import PaymentInitiationAdviceFile
from wallee.models.payment_initiation_advice_file_state import PaymentInitiationAdviceFileState
from wallee.models.payment_link import PaymentLink
from wallee.models.payment_link_address_handling_mode import PaymentLinkAddressHandlingMode
from wallee.models.payment_link_protection_mode import PaymentLinkProtectionMode
from wallee.models.payment_link_update import PaymentLinkUpdate
from wallee.models.payment_method import PaymentMethod
from wallee.models.payment_method_brand import PaymentMethodBrand
from wallee.models.payment_method_configuration import PaymentMethodConfiguration
from wallee.models.payment_primary_risk_taker import PaymentPrimaryRiskTaker
from wallee.models.payment_processor import PaymentProcessor
from wallee.models.payment_processor_configuration import PaymentProcessorConfiguration
from wallee.models.payment_terminal import PaymentTerminal
from wallee.models.payment_terminal_address import PaymentTerminalAddress
from wallee.models.payment_terminal_configuration import PaymentTerminalConfiguration
from wallee.models.payment_terminal_configuration_state import PaymentTerminalConfigurationState
from wallee.models.payment_terminal_configuration_version import PaymentTerminalConfigurationVersion
from wallee.models.payment_terminal_configuration_version_state import PaymentTerminalConfigurationVersionState
from wallee.models.payment_terminal_dcc_transaction_sum import PaymentTerminalDccTransactionSum
from wallee.models.payment_terminal_location import PaymentTerminalLocation
from wallee.models.payment_terminal_location_state import PaymentTerminalLocationState
from wallee.models.payment_terminal_location_version import PaymentTerminalLocationVersion
from wallee.models.payment_terminal_location_version_state import PaymentTerminalLocationVersionState
from wallee.models.payment_terminal_receipt_type import PaymentTerminalReceiptType
from wallee.models.payment_terminal_state import PaymentTerminalState
from wallee.models.payment_terminal_transaction_sum import PaymentTerminalTransactionSum
from wallee.models.payment_terminal_transaction_summary import PaymentTerminalTransactionSummary
from wallee.models.payment_terminal_transaction_summary_fetch_request import PaymentTerminalTransactionSummaryFetchRequest
from wallee.models.payment_terminal_type import PaymentTerminalType
from wallee.models.permission import Permission
from wallee.models.persistable_currency_amount import PersistableCurrencyAmount
from wallee.models.persistable_currency_amount_update import PersistableCurrencyAmountUpdate
from wallee.models.product_fee_type import ProductFeeType
from wallee.models.product_metered_fee import ProductMeteredFee
from wallee.models.product_metered_fee_update import ProductMeteredFeeUpdate
from wallee.models.product_metered_tier_fee import ProductMeteredTierFee
from wallee.models.product_metered_tier_fee_update import ProductMeteredTierFeeUpdate
from wallee.models.product_metered_tier_pricing import ProductMeteredTierPricing
from wallee.models.product_period_fee import ProductPeriodFee
from wallee.models.product_period_fee_update import ProductPeriodFeeUpdate
from wallee.models.product_setup_fee import ProductSetupFee
from wallee.models.product_setup_fee_update import ProductSetupFeeUpdate
from wallee.models.recurring_indicator import RecurringIndicator
from wallee.models.refund import Refund
from wallee.models.refund_comment import RefundComment
from wallee.models.refund_create import RefundCreate
from wallee.models.refund_state import RefundState
from wallee.models.refund_type import RefundType
from wallee.models.rendered_document import RenderedDocument
from wallee.models.rendered_terminal_receipt import RenderedTerminalReceipt
from wallee.models.rendered_terminal_transaction_summary import RenderedTerminalTransactionSummary
from wallee.models.resource_path import ResourcePath
from wallee.models.resource_state import ResourceState
from wallee.models.rest_address_format import RestAddressFormat
from wallee.models.rest_address_format_field import RestAddressFormatField
from wallee.models.rest_country import RestCountry
from wallee.models.rest_country_state import RestCountryState
from wallee.models.rest_currency import RestCurrency
from wallee.models.rest_language import RestLanguage
from wallee.models.role import Role
from wallee.models.role_state import RoleState
from wallee.models.sales_channel import SalesChannel
from wallee.models.scope import Scope
from wallee.models.server_error import ServerError
from wallee.models.shopify_additional_line_item_data import ShopifyAdditionalLineItemData
from wallee.models.shopify_integration import ShopifyIntegration
from wallee.models.shopify_integration_payment_app_version import ShopifyIntegrationPaymentAppVersion
from wallee.models.shopify_integration_subscription_app_version import ShopifyIntegrationSubscriptionAppVersion
from wallee.models.shopify_recurring_order_state import ShopifyRecurringOrderState
from wallee.models.shopify_recurring_order_update_request import ShopifyRecurringOrderUpdateRequest
from wallee.models.shopify_subscriber import ShopifySubscriber
from wallee.models.shopify_subscriber_active import ShopifySubscriberActive
from wallee.models.shopify_subscriber_creation import ShopifySubscriberCreation
from wallee.models.shopify_subscriber_state import ShopifySubscriberState
from wallee.models.shopify_subscription import ShopifySubscription
from wallee.models.shopify_subscription_address_create import ShopifySubscriptionAddressCreate
from wallee.models.shopify_subscription_billing_interval_unit import ShopifySubscriptionBillingIntervalUnit
from wallee.models.shopify_subscription_creation_request import ShopifySubscriptionCreationRequest
from wallee.models.shopify_subscription_model_billing_configuration import ShopifySubscriptionModelBillingConfiguration
from wallee.models.shopify_subscription_model_item import ShopifySubscriptionModelItem
from wallee.models.shopify_subscription_model_tax_line import ShopifySubscriptionModelTaxLine
from wallee.models.shopify_subscription_product import ShopifySubscriptionProduct
from wallee.models.shopify_subscription_product_pricing_option import ShopifySubscriptionProductPricingOption
from wallee.models.shopify_subscription_product_state import ShopifySubscriptionProductState
from wallee.models.shopify_subscription_state import ShopifySubscriptionState
from wallee.models.shopify_subscription_suspension import ShopifySubscriptionSuspension
from wallee.models.shopify_subscription_suspension_create import ShopifySubscriptionSuspensionCreate
from wallee.models.shopify_subscription_suspension_initiator import ShopifySubscriptionSuspensionInitiator
from wallee.models.shopify_subscription_suspension_state import ShopifySubscriptionSuspensionState
from wallee.models.shopify_subscription_suspension_type import ShopifySubscriptionSuspensionType
from wallee.models.shopify_subscription_update_addresses_request import ShopifySubscriptionUpdateAddressesRequest
from wallee.models.shopify_subscription_update_request import ShopifySubscriptionUpdateRequest
from wallee.models.shopify_subscription_version import ShopifySubscriptionVersion
from wallee.models.shopify_subscription_version_item import ShopifySubscriptionVersionItem
from wallee.models.shopify_subscription_version_item_price_strategy import ShopifySubscriptionVersionItemPriceStrategy
from wallee.models.shopify_subscription_version_state import ShopifySubscriptionVersionState
from wallee.models.shopify_subscription_weekday import ShopifySubscriptionWeekday
from wallee.models.shopify_tax_line import ShopifyTaxLine
from wallee.models.shopify_transaction_state import ShopifyTransactionState
from wallee.models.space import Space
from wallee.models.space_address import SpaceAddress
from wallee.models.space_address_create import SpaceAddressCreate
from wallee.models.space_reference import SpaceReference
from wallee.models.space_reference_state import SpaceReferenceState
from wallee.models.space_view import SpaceView
from wallee.models.static_value import StaticValue
from wallee.models.subscriber import Subscriber
from wallee.models.subscriber_update import SubscriberUpdate
from wallee.models.subscription import Subscription
from wallee.models.subscription_affiliate import SubscriptionAffiliate
from wallee.models.subscription_affiliate_update import SubscriptionAffiliateUpdate
from wallee.models.subscription_change_request import SubscriptionChangeRequest
from wallee.models.subscription_charge import SubscriptionCharge
from wallee.models.subscription_charge_create import SubscriptionChargeCreate
from wallee.models.subscription_charge_processing_type import SubscriptionChargeProcessingType
from wallee.models.subscription_charge_state import SubscriptionChargeState
from wallee.models.subscription_charge_type import SubscriptionChargeType
from wallee.models.subscription_component_configuration import SubscriptionComponentConfiguration
from wallee.models.subscription_component_reference_configuration import SubscriptionComponentReferenceConfiguration
from wallee.models.subscription_create_request import SubscriptionCreateRequest
from wallee.models.subscription_ledger_entry import SubscriptionLedgerEntry
from wallee.models.subscription_ledger_entry_create import SubscriptionLedgerEntryCreate
from wallee.models.subscription_ledger_entry_state import SubscriptionLedgerEntryState
from wallee.models.subscription_metric import SubscriptionMetric
from wallee.models.subscription_metric_type import SubscriptionMetricType
from wallee.models.subscription_metric_update import SubscriptionMetricUpdate
from wallee.models.subscription_metric_usage_report import SubscriptionMetricUsageReport
from wallee.models.subscription_metric_usage_report_create import SubscriptionMetricUsageReportCreate
from wallee.models.subscription_period_bill import SubscriptionPeriodBill
from wallee.models.subscription_period_bill_state import SubscriptionPeriodBillState
from wallee.models.subscription_product import SubscriptionProduct
from wallee.models.subscription_product_component import SubscriptionProductComponent
from wallee.models.subscription_product_component_group import SubscriptionProductComponentGroup
from wallee.models.subscription_product_component_group_update import SubscriptionProductComponentGroupUpdate
from wallee.models.subscription_product_component_reference import SubscriptionProductComponentReference
from wallee.models.subscription_product_component_reference_state import SubscriptionProductComponentReferenceState
from wallee.models.subscription_product_component_update import SubscriptionProductComponentUpdate
from wallee.models.subscription_product_retirement import SubscriptionProductRetirement
from wallee.models.subscription_product_retirement_create import SubscriptionProductRetirementCreate
from wallee.models.subscription_product_state import SubscriptionProductState
from wallee.models.subscription_product_version import SubscriptionProductVersion
from wallee.models.subscription_product_version_pending import SubscriptionProductVersionPending
from wallee.models.subscription_product_version_retirement import SubscriptionProductVersionRetirement
from wallee.models.subscription_product_version_retirement_create import SubscriptionProductVersionRetirementCreate
from wallee.models.subscription_product_version_state import SubscriptionProductVersionState
from wallee.models.subscription_state import SubscriptionState
from wallee.models.subscription_suspension import SubscriptionSuspension
from wallee.models.subscription_suspension_action import SubscriptionSuspensionAction
from wallee.models.subscription_suspension_create import SubscriptionSuspensionCreate
from wallee.models.subscription_suspension_reason import SubscriptionSuspensionReason
from wallee.models.subscription_suspension_state import SubscriptionSuspensionState
from wallee.models.subscription_update import SubscriptionUpdate
from wallee.models.subscription_update_request import SubscriptionUpdateRequest
from wallee.models.subscription_version import SubscriptionVersion
from wallee.models.subscription_version_state import SubscriptionVersionState
from wallee.models.tax import Tax
from wallee.models.tax_calculation import TaxCalculation
from wallee.models.tax_class import TaxClass
from wallee.models.tax_create import TaxCreate
from wallee.models.tenant_database import TenantDatabase
from wallee.models.terminal_receipt_fetch_request import TerminalReceiptFetchRequest
from wallee.models.terminal_receipt_format import TerminalReceiptFormat
from wallee.models.token import Token
from wallee.models.token_version import TokenVersion
from wallee.models.token_version_state import TokenVersionState
from wallee.models.token_version_type import TokenVersionType
from wallee.models.tokenization_mode import TokenizationMode
from wallee.models.tokenized_card_data import TokenizedCardData
from wallee.models.tokenized_card_data_create import TokenizedCardDataCreate
from wallee.models.transaction import Transaction
from wallee.models.transaction_aware_entity import TransactionAwareEntity
from wallee.models.transaction_comment import TransactionComment
from wallee.models.transaction_completion_behavior import TransactionCompletionBehavior
from wallee.models.transaction_completion_mode import TransactionCompletionMode
from wallee.models.transaction_completion_request import TransactionCompletionRequest
from wallee.models.transaction_completion_state import TransactionCompletionState
from wallee.models.transaction_environment_selection_strategy import TransactionEnvironmentSelectionStrategy
from wallee.models.transaction_group import TransactionGroup
from wallee.models.transaction_group_state import TransactionGroupState
from wallee.models.transaction_invoice_comment import TransactionInvoiceComment
from wallee.models.transaction_invoice_replacement import TransactionInvoiceReplacement
from wallee.models.transaction_invoice_state import TransactionInvoiceState
from wallee.models.transaction_line_item_version_create import TransactionLineItemVersionCreate
from wallee.models.transaction_line_item_version_state import TransactionLineItemVersionState
from wallee.models.transaction_state import TransactionState
from wallee.models.transaction_user_interface_type import TransactionUserInterfaceType
from wallee.models.transaction_void_mode import TransactionVoidMode
from wallee.models.transaction_void_state import TransactionVoidState
from wallee.models.two_factor_authentication_type import TwoFactorAuthenticationType
from wallee.models.user import User
from wallee.models.user_account_role import UserAccountRole
from wallee.models.user_space_role import UserSpaceRole
from wallee.models.user_type import UserType
from wallee.models.web_app_confirmation_request import WebAppConfirmationRequest
from wallee.models.web_app_confirmation_response import WebAppConfirmationResponse
from wallee.models.webhook_identity import WebhookIdentity
from wallee.models.webhook_listener import WebhookListener
from wallee.models.webhook_listener_entity import WebhookListenerEntity
from wallee.models.webhook_url import WebhookUrl
from wallee.models.account_create import AccountCreate
from wallee.models.account_update import AccountUpdate
from wallee.models.application_user import ApplicationUser
from wallee.models.application_user_create import ApplicationUserCreate
from wallee.models.application_user_update import ApplicationUserUpdate
from wallee.models.authenticated_card_data import AuthenticatedCardData
from wallee.models.charge import Charge
from wallee.models.charge_attempt import ChargeAttempt
from wallee.models.charge_bank_transaction import ChargeBankTransaction
from wallee.models.charge_flow_level import ChargeFlowLevel
from wallee.models.charge_flow_level_payment_link import ChargeFlowLevelPaymentLink
from wallee.models.connector_invocation import ConnectorInvocation
from wallee.models.customer_active import CustomerActive
from wallee.models.customer_address_active import CustomerAddressActive
from wallee.models.customer_address_create import CustomerAddressCreate
from wallee.models.customer_comment_active import CustomerCommentActive
from wallee.models.customer_comment_create import CustomerCommentCreate
from wallee.models.customer_create import CustomerCreate
from wallee.models.debt_collection_case_create import DebtCollectionCaseCreate
from wallee.models.debt_collection_case_update import DebtCollectionCaseUpdate
from wallee.models.delivery_indication import DeliveryIndication
from wallee.models.human_user_create import HumanUserCreate
from wallee.models.human_user_update import HumanUserUpdate
from wallee.models.installment_payment_slice import InstallmentPaymentSlice
from wallee.models.invoice_reconciliation_record import InvoiceReconciliationRecord
from wallee.models.invoice_reimbursement_with_refund_reference import InvoiceReimbursementWithRefundReference
from wallee.models.payment_link_active import PaymentLinkActive
from wallee.models.payment_link_create import PaymentLinkCreate
from wallee.models.refund_bank_transaction import RefundBankTransaction
from wallee.models.refund_comment_active import RefundCommentActive
from wallee.models.refund_comment_create import RefundCommentCreate
from wallee.models.refund_recovery_bank_transaction import RefundRecoveryBankTransaction
from wallee.models.shopify_recurring_order import ShopifyRecurringOrder
from wallee.models.shopify_subscription_address import ShopifySubscriptionAddress
from wallee.models.shopify_subscription_product_create import ShopifySubscriptionProductCreate
from wallee.models.shopify_subscription_product_update import ShopifySubscriptionProductUpdate
from wallee.models.shopify_transaction import ShopifyTransaction
from wallee.models.space_create import SpaceCreate
from wallee.models.space_update import SpaceUpdate
from wallee.models.subscriber_active import SubscriberActive
from wallee.models.subscriber_create import SubscriberCreate
from wallee.models.subscription_affiliate_create import SubscriptionAffiliateCreate
from wallee.models.subscription_affiliate_deleted import SubscriptionAffiliateDeleted
from wallee.models.subscription_affiliate_inactive import SubscriptionAffiliateInactive
from wallee.models.subscription_metric_active import SubscriptionMetricActive
from wallee.models.subscription_metric_create import SubscriptionMetricCreate
from wallee.models.subscription_pending import SubscriptionPending
from wallee.models.subscription_product_active import SubscriptionProductActive
from wallee.models.subscription_product_create import SubscriptionProductCreate
from wallee.models.subscription_suspension_running import SubscriptionSuspensionRunning
from wallee.models.token_create import TokenCreate
from wallee.models.token_update import TokenUpdate
from wallee.models.transaction_comment_active import TransactionCommentActive
from wallee.models.transaction_comment_create import TransactionCommentCreate
from wallee.models.transaction_completion import TransactionCompletion
from wallee.models.transaction_create import TransactionCreate
from wallee.models.transaction_invoice import TransactionInvoice
from wallee.models.transaction_invoice_comment_active import TransactionInvoiceCommentActive
from wallee.models.transaction_invoice_comment_create import TransactionInvoiceCommentCreate
from wallee.models.transaction_line_item_version import TransactionLineItemVersion
from wallee.models.transaction_pending import TransactionPending
from wallee.models.transaction_void import TransactionVoid
from wallee.models.webhook_listener_create import WebhookListenerCreate
from wallee.models.webhook_listener_update import WebhookListenerUpdate
from wallee.models.webhook_url_create import WebhookUrlCreate
from wallee.models.webhook_url_update import WebhookUrlUpdate
from wallee.models.application_user_create_with_mac_key import ApplicationUserCreateWithMacKey
from wallee.models.subscription_affiliate_deleting import SubscriptionAffiliateDeleting
